==> dotnet8_8.0.124-8.0.24.orig.tar.xz: src/roslyn/src/Workspaces/Core/MSBuild.BuildHost/MSBuild/Constants/PropertyNames.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

namespace Microsoft.CodeAnalysis.MSBuild
{
    internal static class PropertyNames
    {
        public const string AllowUnsafeBlocks = nameof(AllowUnsafeBlocks);
        public const string AppConfigForCompiler = nameof(AppConfigForCompiler);
        public const string BaseAddress = nameof(BaseAddress);
        public const string BuildProjectReferences = nameof(BuildProjectReferences);
        public const string BuildingInsideVisualStudio = nameof(BuildingInsideVisualStudio);
        public const string BuildingProject = nameof(BuildingProject);
        public const string CheckForOverflowUnderflow = nameof(CheckForOverflowUnderflow);
        public const string CodePage = nameof(CodePage);
        public const string ContinueOnError = nameof(ContinueOnError);
        public const string DebugSymbols = nameof(DebugSymbols);
        public const string DebugType = nameof(DebugType);
        public const string DefineConstants = nameof(DefineConstants);
        public const string DelaySign = nameof(DelaySign);
        public const string DesignTimeBuild = nameof(DesignTimeBuild);
        public const string DocFileItem = nameof(DocFileItem);
        public const string ErrorReport = nameof(ErrorReport);
        public const string Features = nameof(Features);
        public const string FileAlignment = nameof(FileAlignment);
        public const string FinalDefineConstants = nameof(FinalDefineConstants);
        public const string FrameworkPathOverride = nameof(FrameworkPathOverride);
        public const string GenerateDocumentation = nameof(GenerateDocumentation);
        public const string GenerateFullPaths = nameof(GenerateFullPaths);
        public const string HighEntropyVA = nameof(HighEntropyVA);
        public const string IntermediateAssembly = nameof(IntermediateAssembly);
        public const string KeyContainerName = nameof(KeyContainerName);
        public const string KeyOriginatorFile = nameof(KeyOriginatorFile);
        public const string LangVersion = nameof(LangVersion);
        public const string ModuleAssemblyName = nameof(ModuleAssemblyName);
        public const string NoCompilerStandardLib = nameof(NoCompilerStandardLib);
        public const string NonExistentFile = nameof(NonExistentFile);
        public const string NoWarn = nameof(NoWarn);
        public const string _NoWarnings = nameof(_NoWarnings);
        public const string Optimize = nameof(Optimize);
        public const string OptionCompare = nameof(OptionCompare);
        public const string OptionExplicit = nameof(OptionExplicit);
        public const string OptionInfer = nameof(OptionInfer);
        public const string OptionStrict = nameof(OptionStrict);
        public const string OptionStrictType = nameof(OptionStrictType);
        public const string OutputType = nameof(OutputType);
        public const string PdbFile = nameof(PdbFile);
        public const string PlatformTarget = nameof(PlatformTarget);
        public const string Prefer32Bit = nameof(Prefer32Bit);
        public const string ProvideCommandLineArgs = nameof(ProvideCommandLineArgs);
        public const string RemoveIntegerChecks = nameof(RemoveIntegerChecks);
        public const string ResolvedCodeAnalysisRuleSet = nameof(ResolvedCodeAnalysisRuleSet);
        public const string RootNamespace = nameof(RootNamespace);
        public const string ShouldUnsetParentConfigurationAndPlatform = nameof(ShouldUnsetParentConfigurationAndPlatform);
        public const string SignAssembly = nameof(SignAssembly);
        public const string SkipCompilerExecution = nameof(SkipCompilerExecution);
        public const string StartupObject = nameof(StartupObject);
        public const string SubsystemVersion = nameof(SubsystemVersion);
        public const string TargetCompactFramework = nameof(TargetCompactFramework);
        public const string TargetFramework = nameof(TargetFramework);
        public const string TargetFrameworks = nameof(TargetFrameworks);
        public const string TargetFrameworkIdentifier = nameof(TargetFrameworkIdentifier);
        public const string TargetPath = nameof(TargetPath);
        public const string TargetRefPath = nameof(TargetRefPath);
        public const string TreatWarningsAsErrors = nameof(TreatWarningsAsErrors);
        public const string VbRuntime = nameof(VbRuntime);
        public const string WarningLevel = nameof(WarningLevel);
        public const string WarningsAsErrors = nameof(WarningsAsErrors);
        public const string WarningsNotAsErrors = nameof(WarningsNotAsErrors);
        public const string ChecksumAlgorithm = nameof(ChecksumAlgorithm);
    }
}

==> dotnet9_9.0.110-9.0.9.orig.tar.xz: src/roslyn/src/Workspaces/Core/MSBuild.BuildHost/MSBuild/Constants/PropertyNames.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

namespace Microsoft.CodeAnalysis.MSBuild
{
    internal static class PropertyNames
    {
        public const string AllowUnsafeBlocks = nameof(AllowUnsafeBlocks);
        public const string AppConfigForCompiler = nameof(AppConfigForCompiler);
        public const string BaseAddress = nameof(BaseAddress);
        public const string BuildProjectReferences = nameof(BuildProjectReferences);
        public const string BuildingInsideVisualStudio = nameof(BuildingInsideVisualStudio);
        public const string BuildingProject = nameof(BuildingProject);
        public const string CheckForOverflowUnderflow = nameof(CheckForOverflowUnderflow);
        public const string CodePage = nameof(CodePage);
        public const string ContinueOnError = nameof(ContinueOnError);
        public const string DebugSymbols = nameof(DebugSymbols);
        public const string DebugType = nameof(DebugType);
        public const string DefineConstants = nameof(DefineConstants);
        public const string DelaySign = nameof(DelaySign);
        public const string DesignTimeBuild = nameof(DesignTimeBuild);
        public const string DocFileItem = nameof(DocFileItem);
        public const string ErrorReport = nameof(ErrorReport);
        public const string Features = nameof(Features);
        public const string FileAlignment = nameof(FileAlignment);
        public const string FinalDefineConstants = nameof(FinalDefineConstants);
        public const string FrameworkPathOverride = nameof(FrameworkPathOverride);
        public const string GenerateDocumentation = nameof(GenerateDocumentation);
        public const string GenerateFullPaths = nameof(GenerateFullPaths);
        public const string HighEntropyVA = nameof(HighEntropyVA);
        public const string IntermediateAssembly = nameof(IntermediateAssembly);
        public const string KeyContainerName = nameof(KeyContainerName);
        public const string KeyOriginatorFile = nameof(KeyOriginatorFile);
        public const string LangVersion = nameof(LangVersion);
        public const string ModuleAssemblyName = nameof(ModuleAssemblyName);
        public const string NoCompilerStandardLib = nameof(NoCompilerStandardLib);
        public const string NonExistentFile = nameof(NonExistentFile);
        public const string NoWarn = nameof(NoWarn);
        public const string _NoWarnings = nameof(_NoWarnings);
        public const string Optimize = nameof(Optimize);
        public const string OptionCompare = nameof(OptionCompare);
        public const string OptionExplicit = nameof(OptionExplicit);
        public const string OptionInfer = nameof(OptionInfer);
        public const string OptionStrict = nameof(OptionStrict);
        public const string OptionStrictType = nameof(OptionStrictType);
        public const string OutputType = nameof(OutputType);
        public const string PdbFile = nameof(PdbFile);
        public const string PlatformTarget = nameof(PlatformTarget);
        public const string Prefer32Bit = nameof(Prefer32Bit);
        public const string ProjectAssetsFile = nameof(ProjectAssetsFile);
        public const string ProvideCommandLineArgs = nameof(ProvideCommandLineArgs);
        public const string RemoveIntegerChecks = nameof(RemoveIntegerChecks);
        public const string ResolvedCodeAnalysisRuleSet = nameof(ResolvedCodeAnalysisRuleSet);
        public const string RootNamespace = nameof(RootNamespace);
        public const string ShouldUnsetParentConfigurationAndPlatform = nameof(ShouldUnsetParentConfigurationAndPlatform);
        public const string SignAssembly = nameof(SignAssembly);
        public const string SkipCompilerExecution = nameof(SkipCompilerExecution);
        public const string StartupObject = nameof(StartupObject);
        public const string SubsystemVersion = nameof(SubsystemVersion);
        public const string TargetCompactFramework = nameof(TargetCompactFramework);
        public const string TargetFramework = nameof(TargetFramework);
        public const string TargetFrameworks = nameof(TargetFrameworks);
        public const string TargetFrameworkIdentifier = nameof(TargetFrameworkIdentifier);
        public const string TargetFrameworkVersion = nameof(TargetFrameworkVersion);
        public const string TargetPath = nameof(TargetPath);
        public const string TargetRefPath = nameof(TargetRefPath);
        public const string TreatWarningsAsErrors = nameof(TreatWarningsAsErrors);
        public const string VbRuntime = nameof(VbRuntime);
        public const string WarningLevel = nameof(WarningLevel);
        public const string WarningsAsErrors = nameof(WarningsAsErrors);
        public const string WarningsNotAsErrors = nameof(WarningsNotAsErrors);
        public const string ChecksumAlgorithm = nameof(ChecksumAlgorithm);
    }
}
